%define username   memcached
%define groupname  memcached
%bcond_with tests
%global selinuxtype	targeted
%global selinuxmoduletype	contrib
%global selinuxmodulename	memcached
%global selinuxmodulever	1.0.2
%global selinuxmoduledir	%{selinuxmodulename}-selinux-%{selinuxmodulever}

Summary:        High Performance, Distributed Memory Object Cache
Name:           memcached
Version:        1.6.17
Release:        4%{?dist}
License:        BSD
URL:            https://www.memcached.org/
Source0:        https://www.memcached.org/files/%{name}-%{version}.tar.gz
Source1:        memcached.sysconfig
Source2:        https://releases.pagure.org/memcached-selinux/memcached-selinux-1.0.2.tar.gz
Source3:	memcached.conf

Patch3000:      memcached-unit.patch

BuildRequires: perl(Test::More), perl(Test::Harness) cyrus-sasl-devel  openssl-devel
BuildRequires: make gcc libevent-devel systemd perl-generators
BuildRequires: systemd-rpm-macros


Requires(pre):  shadow-utils
Requires: (%{name}-selinux if selinux-policy-targeted)
%{?systemd_requires}

%description
memcached is a high-performance, distributed memory object caching
system, generic in nature, but intended for use in speeding up dynamic
web applications by alleviating database load.

%package devel
Summary: Files needed for development using memcached protocol
Requires: %{name} = %{version}-%{release}

%description devel
Install memcached-devel if you are developing C/C++ applications that require
access to the memcached binary include files.

%package selinux
Summary: Selinux policy module
License: GPLv2
BuildRequires: selinux-policy
%{?selinux_requires}

%description selinux
Install memcached-selinux to ensure your system contains the latest SELinux policy
optimised for use with this version of memcached.

%prep
%autosetup -p1 -b 2

%build
%configure \
  --enable-sasl --enable-sasl-pwdb \
  --enable-tls

%make_build

pushd ../%{selinuxmoduledir}
make
popd

%check
%if %{with tests}
rm -f t/whitespace.t

if [ `id -u` -ne 0 ]; then
  rm -f t/daemonize.t t/watcher.t t/expirations.t
fi
make test
%endif

%install
%make_install

rm -f %{buildroot}/%{_bindir}/memcached-debug

install -Dp -m0755 scripts/memcached-tool %{buildroot}%{_bindir}/memcached-tool
install -Dp -m0644 scripts/memcached-tool.1 \
        %{buildroot}%{_mandir}/man1/memcached-tool.1

install -Dp -m0644 scripts/memcached.service \
        %{buildroot}%{_unitdir}/memcached.service

install -Dp -m0644 %{SOURCE1} %{buildroot}/%{_sysconfdir}/sysconfig/%{name}

pushd ../%{selinuxmoduledir}
install -d %{buildroot}%{_datadir}/selinux/packages
install -d -p %{buildroot}%{_datadir}/selinux/devel/include/%{selinuxmoduletype}
install -m 0644 %{selinuxmodulename}.pp.bz2 %{buildroot}%{_datadir}/selinux/packages
popd

install -p -D -m 0644 %{SOURCE3} %{buildroot}%{_sysusersdir}/memcached.conf

%pre
%sysusers_create_compat %{SOURCE3}

%pre selinux
%selinux_relabel_pre -s %{selinuxtype}

%post
%systemd_post memcached.service

%post selinux
%selinux_modules_install -s %{selinuxtype} -p 200 %{_datadir}/selinux/packages/%{selinuxmodulename}.pp.bz2 &> /dev/null

%preun
%systemd_preun memcached.service


%postun
%systemd_postun_with_restart memcached.service

%postun selinux
if [ $1 -eq 0 ]; then
    %selinux_modules_uninstall -s %{selinuxtype} -p 200 %{selinuxmodulename}
fi

%posttrans selinux
%selinux_relabel_post -s %{selinuxtype} &> /dev/null

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README.md doc/CONTRIBUTORS doc/*.txt
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_bindir}/memcached-tool
%{_bindir}/memcached
%{_unitdir}/memcached.service
%{_sysusersdir}/memcached.conf
%{_mandir}/man1/memcached-tool.1*
%{_mandir}/man1/memcached.1*

%files devel
%{_includedir}/memcached/*

%files selinux
%license ../%{selinuxmoduledir}/COPYING
%attr(0644,root,root) %{_datadir}/selinux/packages/%{selinuxmodulename}.pp.bz2
%ghost %{_sharedstatedir}/selinux/%{selinuxtype}/active/modules/200/%{selinuxmodulename}

%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.6.17-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.6.17-3
- Rebuilt for OpenCloudOS Stream 23

* Mon Mar 13 2023 cunshunxia <cunshunxia@tencent.com> - 1.6.17-2
- use macros to build.

* Fri Mar 10 2023 cunshunxia <cunshunxia@tencent.com> - 1.6.17-1
- initial build
